#!/bin/bash
#
# N.B. script MUST be localized by editing lines 17, 21 and 24 for your site!
#
# wrapper script to be able to run mogul with -datapath and -csdpath options
# set. These need to be set to local directories. Idea is to provide a
# work around for NFS issues (particularly v3 stall problem).
#
# For details on how to set up and use please see BUSTER wiki page:
# https://www.globalphasing.com/buster/wiki/index.cgi?SoftwareMogulWrapper
#
# author Oliver Smart buster-develop@globalphasing.com
# v1.04 28 April 2014

# edit the next line to the location of the CSDS home directory (in nfs mounted directory)
# this should contain directory bin with the mogul executable in it
export CSDHOME="/nfs/CSDS2014/"
MYMOGUL="$CSDHOME/bin/mogul"
# edit the next line to "path to mogul <data_directory>" should contain
# the file mogul534.path"
MYDATAPATH="/local/osmart/csdslocal/data"
# edit the next line to provide the full path for the file 
# csd/as535be.inf but do include the final ".inf"
MYCSDPATH="/local/osmart/csdslocal/csd/as535be"

# script arguments these MUST be passed to mogul
MYARGS="$@"
echo "using mogul executable $MYMOGUL"
# check it is executable
if [[ ! -x $MYMOGUL ]]
then
    echo "ERROR in $0 wrapper '$MYMOGUL' is not executable"
    exit 1;
fi

# the datapath directory must contain file mogul*.path
MYMOGULPATH=`find $MYDATAPATH -maxdepth 1  -name 'mogul*.path' -print`
if [[ -f  $MYMOGULPATH ]]
then
    echo "using -datapath $MYDATAPATH as $MYMOGULPATH exists"
    MYARGS="$MYARGS -datapath $MYDATAPATH"
else
    echo "ERROR in $0 wrapper '$MYDATAPATH' does not contain any file mogul*.path?"
    exit 1;
fi      

# the csdpath directory must contain file as*be.inf
MYASBEINF="$MYCSDPATH.inf"
if [[ -f  $MYASBEINF ]]
then
    echo "using -csdpath $MYCSDPATH as $MYASBEINF exists"
    MYARGS="$MYARGS -csdpath $MYCSDPATH"
else
    echo "ERROR in $0 wrapper '$MYCSDPATH' specified but the file $MYASBEINF does not exist?"
    exit 1;
fi      

# finally exec mogul with modified arguments
exec $MYMOGUL $MYARGS
